@@ -1,13 +1,6 @@
 opttdev <- function (veg,clustering,maxitr=100,minsiz=5) 
 {
-    if (inherits(clustering, c("partana", "clustering", "partition"))) 
-        clustering <-  clustering$clustering
-    if (is.numeric(clustering)) {
-        if (min(clustering)< 0 || (length(table(clustering)) != max(clustering))) {
-            cat('WARNING: renumbering clusters to consecutive integers\n')
-            clustering <- match(clustering,sort(unique(clustering)))
-        }
-    }
+    clustering <- as.numeric(clustify(clustering))
 
     numplt <- nrow(veg)
     numspc <- ncol(veg)
